package com.collabnet.labmanagement.api;
import java.io.IOException;



public interface GeneratedCubit {

    /**
     * Check the setup of all hosts in the domain to make sure their representation is internally complete within Lab Management. This method is only available to users to Lab Management Domain Admins and can be considered a maintenance method that should rarely, if ever, need to be run. Three areas of setup consistency are checked for each host:<br> <ol> <li>Verification and re-application of the host's internal database representation within Lab Management. This may be needed after an upgrade of the Lab Management application is installed. </li> <li>Verification that the IP address assigned to the host matches the hostname. If you suspect DNS setup issues in your domain, this test should catch them (unless the errors are transient). Lab Management  will not let you create hosts with invalid DNS, but if DNS for the host gets changed improperly after the host is created, your host will experience many problems in the Lab Management environment until it is fixed. </li> <li>Verification of the IP mask/gateway configured for the host with the actual one it resolves to. </li> <li>Re-generation of statistics system performance monitoring  configuration files for the host. If monitoring is not properly working for a host, regenerating the configuration files will usually fix the problem. </li> </ol> Depending on the number of hosts in your domain, this method can take some time to complete. If you have questions on the output of this method, please see your local Lab Management Administrator or contact CollabNet directly for assistance. 
     *
     * <h2>Example Response</h2>
     * <pre>
     * 
    Successful completion of host consistency check:
    &lt;?xml version='1.0'?&gt;
    &lt;cubit version='1'&gt;
        &lt;status&gt;OK&lt;/status&gt;
        &lt;output&gt;All Hosts OK&lt;/output&gt;
    &lt;/cubit&gt;

    If the user is not a Lab Management Domain Admin:
    &lt;?xml version='1.0'?&gt;
    &lt;cubit version='1'&gt;
        &lt;error&gt;User 'grue' is not authorized to run this method.&lt;/error&gt;
    &lt;/cubit&gt;

    If there is an error re-generating the host's internal database 
    representation for at least one host:
    &lt;?xml version='1.0'?&gt;
    &lt;cubit version='1'&gt;
        &lt;status&gt;OK&lt;/status&gt;
            &lt;output&gt;Hosts which were not successfully updated:
            cu011.dev.cubitdemo.net&lt;/output&gt;
    &lt;/cubit&gt;

    If the system performance statistics configuration files are not
    properly generated for at least one host:
    &lt;?xml version='1.0'?&gt;
    &lt;cubit version='1'&gt;
        &lt;status&gt;OK&lt;/status&gt;
            &lt;output&gt;Hosts which are not properly setup to collect
            performance data: cu011.dev.cubitdemo.net&lt;/output&gt;
    &lt;/cubit&gt;

    If there is a DNS mismatch for at least one host:
    &lt;?xml version='1.0'?&gt;
    &lt;cubit version='1'&gt;
        &lt;status&gt;OK&lt;/status&gt;
            &lt;output&gt;Hosts which require re-ip'ing:
            cu011.dev.cubitdemo.net&lt;/output&gt;
    &lt;/cubit&gt;

    If there is a IP mask mis-match:
    &lt;?xml version='1.0'?&gt;
    &lt;cubit version='1'&gt;
        &lt;status&gt;OK&lt;/status&gt;
            &lt;output&gt;Hosts whose IP mask/gateway does not match with the
            IP mask/gateway it resolves to:
            cu011.dev.cubitdemo.net&lt;/output&gt;
    &lt;/cubit&gt;

    
     * </pre>
  */
    @Signed
    @CgiMethod("check_host_consistency")
    @Version(1)
    public Response checkHostConsistency(
) throws IOException;


    /**
     *  Create one or more hosts from a cloud given the host-type and size. The cloud will match the host-type and size to one (or more) source(s) from the cloud in order to fill the entire order. Host types and sizes cannot be mixed in a single API call. All the hosts must be the same type/size. The method will fail if the cloud's sources cannot accomodate that many hosts of the given type/size. <p>Any user who is a member of a project that has been given permission to allocate from this cloud can create instances. </p> 
     *
     * <h2>Example Response</h2>
     * <pre>
     * 
    Successful allocation of 10 instances:
    &lt;?xml version='1.0'?&gt;
    &lt;cubit version='1'&gt;
        &lt;status&gt;OK&lt;/status&gt;
        &lt;output&gt;ec2-pending-1204832590-85&lt;/output&gt;
        &lt;output&gt;ec2-pending-1204832595-09&lt;/output&gt;
        &lt;output&gt;ec2-pending-1204832599-97&lt;/output&gt;
        &lt;output&gt;ec2-pending-1204832611-49&lt;/output&gt;
        &lt;output&gt;ec2-pending-1204832615-60&lt;/output&gt;
        &lt;output&gt;ec2-pending-1204832620-29&lt;/output&gt;
        &lt;output&gt;ec2-pending-1204832624-25&lt;/output&gt;
        &lt;output&gt;ec2-pending-1204832628-46&lt;/output&gt;
        &lt;output&gt;ec2-pending-1204832640-90&lt;/output&gt;
        &lt;output&gt;ec2-pending-1204832645-60&lt;/output&gt;
    &lt;/cubit&gt;

    &lt;?xml version='1.0'?&gt;
    &lt;cubit version='1'&gt;
        &lt;status&gt;OK&lt;/status&gt;
    &lt;/cubit&gt;

    If the user lacks permission to create hosts in the project:
    &lt;?xml version='1.0'?&gt;
    &lt;cubit version='1'&gt;
        &lt;error&gt;You are not authorized to create hosts in this project.&lt;/error&gt;
    &lt;/cubit&gt;

    If the project does not have the permissions to allocate from the
    requested cloud:
    &lt;?xml version='1.0'?&gt;
    &lt;cubit version='1'&gt;
        &lt;error&gt;This project is not authorized to create hosts in this cloud.&lt;/error&gt;
    &lt;/cubit&gt;

    If the cloud does not have enough space on the sources to allocate that many hosts:
    &lt;?xml version='1.0'?&gt;
    &lt;cubit version='1'&gt;
        &lt;error&gt;This cloud does not have enough resources to create [n] hosts.&lt;/error&gt;
    &lt;/cubit&gt;
    
     * </pre>
  
      * @param host_type (required)
            The name of the host_type of machine to create. Must be one of the host-types supported by the cloud.
  
      * @param alloc_minutes 
            Similar to alloc_hours parameter, but in minutes. It is mutually exclusive with the <code>alloc_hours</code>  option, neither of these options should be specified, or only one  of these options should be specified. If <code>alloc_hours</code> or <code>alloc_minutes</code> is set to 0, or if <code>alloc_hours</code> and <code>alloc_minutes</code> is unset, the allocation time defaults to the longest possible time available in the project. 
  
      * @param alloc_hours 
            Amount of time for which to allocate the host. The allocation limit is subject to the limit set by the project or cloud administrator. 
  
      * @param revision 
            Revision number of the profile you wish to assign to the host. Mutually exclusive with the <code>version</code> option, but at  least one of the <code>version</code> or <code>revision</code> options must be specified.
  
      * @param descr 
            Set the specified string as a description for the allocated hosts. This is useful if you wish to uniquely identify a group of hosts which have all been allocated to the same user at the same time for the same purpose.
  
      * @param profile (required)
            Name of the profile to assign to the host. The profile must, of course, be a profile that is eligible to be built by the host-type/size you selected.
  
      * @param size (required)
            The name of the machine size to create. Must be one of the sizes supported by the given host_type.
  
      * @param version 
            Version number or tag name of the profile you wish to assign to the host. The special version tag <code><strong>HEAD</strong></code> always denotes the latest version of the profile at the moment of execution. Note that profile tags can move between versions: this is a useful feature, but you should be aware of it. Mutually exclusive with the <code>revision</code> option, but at  least one of the <code>version</code> or <code>revision</code> options must be specified.
  
      * @param project (required)
            Name of Lab Management project to place hosts into. You must have permission to add hosts to this project: that is, you must either be a Project Admin or Delegated Host Management must be turned on in your project.
  
      * @param count 
            The number of identical instances to bring up. The instances will all be running the same profile and version. Must be an integer greater than 0. If unset, defaults to 1.
  
      * @param dont_delete 
            By default, EC2 instances will automatically be deleted when they are deallocated. If  <code>dont_delete</code> is set to True, the instances created will not be deleted when they are deallocated, and will instead revert back to the project pool.
  
      * @param cloud (required)
            Name of Lab Management cloud to allocate instances from.
  */
    @Signed
    @CgiMethod("allocate_hosts_from_cloud")
    @Version(1)
    public Response cloudCreateHosts(
        @Required @Param("host_type") String host_type,
        @Param("alloc_minutes") Integer alloc_minutes,
        @Param("alloc_hours") Float alloc_hours,
        @Param("revision") Integer revision,
        @Param("descr") String  descr,
        @Required @Param("profile") String profile,
        @Required @Param("size") String size,
        @Param("version") String version,
        @Required @Param("project") String project,
        @Param("count") Integer count,
        @Param("dont_delete") String dont_delete,
        @Required @Param("cloud") String cloud) throws IOException;


    /**
     *  GetAuthToken(userid) -> token 
     *
     * <h2>Example Response</h2>
     * <pre>
     * 
     * </pre>
  */
    @CgiMethod("get_auth_token")
    @Version(1)
    public Response getAuthToken(
) throws IOException;


    /**
     *  Allocate a host to a user. Hosts must be in the <code>Free</code> state to be allocated, although users with Project Admin access can re-allocate hosts which are in the <code>Allocated</code> state to other users in their project. Domain Admin users can re-allocate machines between projects and users, although if a machine is reallocated to a user in another project, that user must also be a member of the  destination project. The user must be authorized to allocate the host. The host must also not be in any of the following states: <code>Immutable</code>, <code>Powercycle</code>, <code>Rebuild</code>, or <code>Rebuilding</code>, or this method will fail. 
     *
     * <h2>Example Response</h2>
     * <pre>
     * 
    Successful host allocation:
    &lt;?xml version='1.0'?&gt;
    &lt;cubit version='1'&gt;
        &lt;status&gt;OK&lt;/status&gt;
    &lt;/cubit&gt;

    If the user is unauthorized, or the host does not exist:
    &lt;?xml version='1.0'?&gt;
    &lt;cubit version='1'&gt;
        &lt;error&gt;You are not authorized to allocate this host.&lt;/error&gt;
    &lt;/cubit&gt;

    If the host is allocated to a deleted project:
    &lt;?xml version='1.0'?&gt;
    &lt;cubit version='1'&gt;
        &lt;error&gt;Cannot allocate host 'cu001.dev.cubitdemo.net' to a
        deleted project 'look'&lt;/error&gt;
    &lt;/cubit&gt;
    
     * </pre>
  
      * @param host (required)
            Fully qualified hostname to allocate.
  
      * @param alloc_minutes 
            Similar to alloc_hours parameter, but in minutes. It is mutually exclusive with the <code>alloc_hours</code>  option, neither of these options should be specified, or only one  of these options should be specified. If <code>alloc_hours</code> or <code>alloc_minutes</code> is set to 0, or if <code>alloc_hours</code> and <code>alloc_minutes</code> is unset, the allocation time defaults to the longest possible time available in the project. 
  
      * @param force 
            If the machine is currently in the <code><strong>Allocated</strong></code> state, the <code>force</code> option must be given to reassign the host to another user. The <code>force</code> option is only available to Project Admins and above. If the host is a virtual host, and any virtual guests of this host are in the <code><strong>Allocated</strong></code> state, this option must also be used, or the entire allocation will fail. The only valid value for this parameter is <code>True</code>.
  
      * @param alloc_hours 
            Amount of time for which to allocate the host. The allocation limit is subject to the limit set by the project or cloud administrator. 
  
      * @param alloc_proj 
            The project to allocate the machine to. The <code>alloc_user</code> must be a valid Lab Management user in the project, or else this method will fail. Only Domain Admins can change the project that a host is assigned to.  If not specified, the project is not changed. At least one of <code>alloc_user</code> or <code>alloc_proj</code> must be specified.
  
      * @param alloc_user 
            Login name of user to allocate  host to. Only Project Admins or better can specify a user other than themselves. Other users can only allocate machines to themselves. If not specified, defaults to <code>userid</code>. At least one of <code>alloc_user</code> or <code>alloc_proj</code> must be specified.
  
      * @param guests 
            If the machine is a virtual host and has active virtual guests, setting this parameter to <code>True</code> will move the virtual guests along with the virtual host. Because moving a virtual host will move several hosts at once, we have a separate parameter to confirm this action. The only valid value for this parameter is <code>True</code>. If the host has no virtual guests, this option has no effect.
  */
    @Signed
    @CgiMethod("alloc_host")
    @Version(1)
    public Response hostAllocate(
        @Required @Param("host") String host,
        @Param("alloc_minutes") Integer alloc_minutes,
        @Param("force") String force,
        @Param("alloc_hours") Float alloc_hours,
        @Param("alloc_proj") String alloc_proj,
        @Param("alloc_user") String alloc_user,
        @Param("guests") String guests) throws IOException;


    /**
     *  Assign a profile to the host and rebuild it with that profile/version. The user must be authorized to rebuild the host. The host must not be in any of the states which disallow rebuilding, such as  <code>Immutable</code>, <code>Rebuild</code>, or <code>Rebuilding</code>, or this method will fail. The host must also not be of a type which prohibits rebuilding (e.g., an EC2 host). If you do not want to change the profile a host is running, and just want to rebuild a host, you can save a few keystrokes and use the Rebuild method instead. 
     *
     * <h2>Example Response</h2>
     * <pre>
     * 
    Successful initiation of rebuild:
    &lt;?xml version='1.0'?&gt;
    &lt;cubit version='1'&gt;
        &lt;status&gt;OK&lt;/status&gt;
    &lt;/cubit&gt;

    If the user is unauthorized, or the host does not exist:
    &lt;?xml version='1.0'?&gt;
    &lt;cubit version='1'&gt;
        &lt;error&gt;You are not authorized to allocate a profile to this host and rebuild it.&lt;/error&gt;
    &lt;/cubit&gt;
    
     * </pre>
  
      * @param host (required)
            Fully qualified hostname to assign profile to and rebuild.
  
      * @param revision 
            Revision number of the profile you wish to assign to the host. Mutually exclusive with the <code>version</code> option, but at  least one of the <code>version</code> or <code>revision</code> options must be specified.
  
      * @param version 
            Version number or tag name of the profile you wish to assign to the host. The special version tag <code><strong>HEAD</strong></code> always denotes the latest version of the profile at the moment of execution. Note that profile tags can move between versions: this is a useful feature, but you should be aware of it. Mutually exclusive with the <code>revision</code> option, but at  least one of the <code>version</code> or <code>revision</code> options must be specified.
  
      * @param profile (required)
            Name of the profile to assign to the host.
  */
    @Signed
    @CgiMethod("assign_rebuild")
    @Version(1)
    public Response hostAssignProfileAndRebuild(
        @Required @Param("host") String host,
        @Param("revision") String revision,
        @Param("version") String version,
        @Required @Param("profile") String profile) throws IOException;


    /**
     *  Delete one or more hosts. The host must not be in the <code>Immutable</code> state for this method to work. Hosts can be deleted by users under the following conditions: <ol> <li>Lab Management Domain Admins can delete any host, regardless if it is physical, virtual, or from a remote cloud</li> <li>Users who are <i>not</i> Lab Management Domain Admins can delete <i>virtual guests</i> if the parent host is allocated to them and Delegated Host Management is turned on in their project. </li> <li>Users who are <i>not</i> Lab Management Domain Admins can also delete <i>remote cloud</i> hosts allocated to them if Delegated Host Management is turned on in their project. </li> </ol>  
     *
     * <h2>Example Response</h2>
     * <pre>
     * 
    Successful host delete of the host cu011.cubit.example.com:
    &lt;?xml version='1.0'?&gt;
    &lt;cubit version='1'&gt;
        &lt;status&gt;OK&lt;/status&gt;
        &lt;output&gt;cu011.cubit.example.com&lt;/output&gt;
    &lt;/cubit&gt;

    If the user is unauthorized:
    &lt;?xml version='1.0'?&gt;
    &lt;cubit version='1'&gt;
        &lt;error&gt;0 of 1 hosts deleted successfully. Failed hosts below.&lt;/error&gt;
        &lt;output&gt;cu013.cubit.example.com: You are not authorized to delete this host.&lt;/output&gt;
    &lt;/cubit&gt;

    If a deletion of hosts partially succeeds:
    &lt;?xml version='1.0'?&gt;
    &lt;cubit version='1'&gt;
        &lt;error&gt;6 of 8 hosts deleted successfully. Failed hosts below.&lt;/error&gt;
        &lt;output&gt;cu013.cubit.example.com: You are not authorized to delete this host&lt;/output&gt;
        &lt;output&gt;cu016.cubit.example.com: Host deletion failed&lt;/output&gt;
    &lt;/cubit&gt;

     * </pre>
  
      * @param hosts (required)
            List of comma-separated, fully qualified hostnames to delete. Hosts must not be in the <code>Immutable</code> state.
  
      * @param force 
            If the machine being deleted does not belong to the user initiating the request, the <code>force</code> option is required. The only valid value for this parameter is <code>True</code>.
  
      * @param guests 
            If the machine is a virtual host and has active virtual guests, setting this parameter to <code>True</code> will delete the virtual guests along with the virtual host. Because deleting a virtual host will delete several hosts at once, we have a separate parameter to confirm this action. The only valid value for this parameter is <code>True</code>. If the host has no virtual guests, this option has no effect. Use of this option can be really convenient, or it can really ruin someone's day!
  */
    @Signed
    @CgiMethod("delete_host")
    @Version(1)
    public Response hostDelete(
        @Required @Param("hosts") String hosts,
        @Param("force") String force,
        @Param("guests") String guests) throws IOException;


    /**
     *  Free a host currently assigned to a user. Hosts must be in the <code>Allocated</code> state to be freed. A user can only free hosts already assigned to them, although Project Admins and Domain Admins can free hosts in their project which are currently allocated. If it is a virtual guest and "Delete on Deallocation" flag is ON, the virtual guest would be deleted after it is set Free.  
     *
     * <h2>Example Response</h2>
     * <pre>
     * 
    Successful freeing of host:
    &lt;?xml version='1.0'?&gt;
    &lt;cubit version='1'&gt;
        &lt;status&gt;OK&lt;/status&gt;
    &lt;/cubit&gt;

    If the user is unauthorized, or the host does not exist:
    &lt;?xml version='1.0'?&gt;
    &lt;cubit version='1'&gt;
        &lt;error&gt;You are not authorized to free this host.&lt;/error&gt;
    &lt;/cubit&gt;
    
     * </pre>
  
      * @param host (required)
            Fully qualified hostname to free. Hosts must be in the <code>Allocated</code> state to be freed.
  
      * @param force 
            If the machine being freed does not belong to the user initiating the request, the <code>force</code> option is required. Only Project Admins and Domain Admins can free hosts which do not belong to them. The only valid value for this parameter is <code>True</code>.
  */
    @Signed
    @CgiMethod("free_host")
    @Version(1)
    public Response hostFree(
        @Required @Param("host") String host,
        @Param("force") String force) throws IOException;


    /**
     *  Gets the assigned profile for the host, and returns the profile name along with the revision and version number. Output is available in both text and XML formats. You can also get this information from the <a href="api_QueryAlloc.html">QueryAlloc</a> method, but the output of this method is easier to parse if you have scripts checking a profile. The user requesting information about a host must have at least login privileges to that host. 
     *
     * <h2>Example Response</h2>
     * <pre>
     * 
    Sample XML output:
    &lt;?xml version='1.0'?&gt;
    &lt;cubit version='1'&gt;
      &lt;profile revision="1838" version="5"&gt;solaris10_x86&lt;/profile&gt;
    &lt;/cubit&gt;

    Sample text output:
    solaris10_x86  1838  5

    If user is unauthorized:
    &lt;?xml version='1.0'?&gt;
    &lt;cubit version='1'&gt;
        &lt;error&gt;You do not have permissions to view this host&lt;/error&gt;
    &lt;/cubit&gt;
    
     * </pre>
  
      * @param output (required)
            Output type, either 'txt' (for text output) or 'xml' (for XML output).
  
      * @param host (required)
            Fully qualified hostname to query.
  */
    @Signed
    @CgiMethod("assigned_profile")
    @Version(1)
    public Response hostGetAssignedProfile(
        @Required @Param("output") String output,
        @Required @Param("host") String host) throws IOException;


    /**
     *  Gets the profile and version assigned to the host invoking this method. 
     *
     * <h2>Example Response</h2>
     * <pre>
     * 
    Sample XML output:
    &lt;?xml version='1.0'?&gt;
    &lt;cubit version='1'&gt;
      &lt;profile revision="26" version="2"&gt;rhel3_base&lt;/profile&gt;
    &lt;/cubit&gt;

    Sample text output:
    rhel3_base  26  2
    
     * </pre>
  
      * @param output (required)
            Output type, either 'txt' (for text output) or 'xml' (for XML output).
  */
    @CgiMethod("my_profile")
    @Version(1)
    public Response hostGetMyAssignedProfile(
        @Required @Param("output") String output) throws IOException;


    /**
     * <p>The HostPerfColl method receives performance collection data from remote hosts managed by Lab Management. </p> <p>This method takes one parameter, <code>data</code>. The hostname is auto-derived using reverse DNS. There is no other way to verify the sending host. </p> <p>The currently supported statgroups are: </p> <p> <b>net</b> Returns a dictionary of network interface transfer metrics. The key is the name of the interface. Value is a tuple containing: (<i>bytes_in, bytes_out, errors_in, errors_out, pkts_in, pkts_out</i>) </p> <p> <b>loadavg</b> Returns a tuple containing the (1, 5, 15) minute load average on the system. </p> <p> <b>storage</b> Returns a dictionary of disk storage metrics. The key is the name of the mounted partition and the value is a tuple of: (<i>block_size, blocks_avail, blocks_used, block_errors</i>) </p> <p> <b>systatd</b> Returns a string containing the systatd output file for the system. </p> 
     *
     * <h2>Example Response</h2>
     * <pre>
     * 
     * </pre>
  */
    @CgiMethod("host_perfcoll")
    @Version(1)
    public Response hostPerfColl(
) throws IOException;


    /**
     *  Powercycle a host. This method immediately executes a powercycle of the host. No graceful shutdown is run on the host at the operating system level. It is recommended that this method only be run when the normal operating shutdown/reboot sequence has failed or is unavailable. You can only powercycle machines in the <code>Allocated</code>, <code>Free</code>, and <code>Immutable</code> states. 
     *
     * <h2>Example Response</h2>
     * <pre>
     * 
    Successful completion of powercycle:
    &lt;?xml version='1.0'?&gt;
    &lt;cubit version='1'&gt;
        &lt;status&gt;OK&lt;/status&gt;
    &lt;/cubit&gt;

    If the user is unauthorized, or the host does not exist:
    &lt;?xml version='1.0'?&gt;
    &lt;cubit version='1'&gt;
        &lt;error&gt;You are not authorized to powercycle this host.&lt;/error&gt;
    &lt;/cubit&gt;
    
     * </pre>
  
      * @param force 
            If the machine being powercycled is a virtual host, the <code>force</code> option is required. The only valid value for this parameter is <code>True</code>.
  
      * @param host (required)
            Fully qualified hostname to powercycle.
  */
    @Signed
    @CgiMethod("powercycle")
    @Version(1)
    public Response hostPowercycle(
        @Param("force") String force,
        @Required @Param("host") String host) throws IOException;


    /**
     *  Cancel a rebuild for a host. The host must be in  <code>Rebuild</code> state for this method to work. In order to cancel a rebuild for a host, the user must have permission to rebuild the host, that is, they must either: <ol> <li>Have the host allocated to them</li> <li>Be a Lab Management Project Admin in the project, or</li> <li>Be a Lab Management Domain Admin</li> </ol>  
     *
     * <h2>Example Response</h2>
     * <pre>
     * 
    Successful host rebuild cancel:
    &lt;?xml version='1.0'?&gt;
    &lt;cubit version='1'&gt;
        &lt;status&gt;OK&lt;/status&gt;
    &lt;/cubit&gt;

    If the user is unauthorized:
    &lt;?xml version='1.0'?&gt;
    &lt;cubit version='1'&gt;
        &lt;error&gt;You are not authorized to cancel a rebuild for this host.&lt;/error&gt;
    &lt;/cubit&gt;
    
     * </pre>
  
      * @param host (required)
            Fully qualified hostname to cancel rebuild of. Hosts must be in the <code>Rebuild</code> state.
  */
    @Signed
    @CgiMethod("rebuild_cancel")
    @Version(1)
    public Response hostRebuildCancel(
        @Required @Param("host") String host) throws IOException;


    /**
     *  Rebuild a host with the currently selected profile and profile version. The user must be authorized to rebuild the host. The host must also not be in any of the states which prohibit rebuilding, such as <code>Immutable</code>, <code>Powercycle</code>, <code>Rebuild</code>, or <code>Rebuilding</code>, or this method will fail. The host must also indicate that it is rebuildable (e.g., not an EC2 host), or this method  will fail. 
     *
     * <h2>Example Response</h2>
     * <pre>
     * 
    Successful initiation of rebuild:
    &lt;?xml version='1.0'?&gt;
    &lt;cubit version='1'&gt;
        &lt;status&gt;OK&lt;/status&gt;
    &lt;/cubit&gt;

    If the user is unauthorized, or the host does not exist:
    &lt;?xml version='1.0'?&gt;
    &lt;cubit version='1'&gt;
        &lt;error&gt;You are not authorized to rebuild this host.&lt;/error&gt;
    &lt;/cubit&gt;
    
     * </pre>
  
      * @param host (required)
            Fully qualified hostname to rebuild.
  */
    @Signed
    @CgiMethod("rebuild")
    @Version(1)
    public Response hostRebuild(
        @Required @Param("host") String host) throws IOException;


    /**
     *  Project Build Library (PBL) file and directory description changing interface. This function is used to change the description for files and directories in the Project Build Library. <strong>Unless you are building your own PBL client, this function will not be very useful to you.</strong> 
     *
     * <h2>Example Response</h2>
     * <pre>
     * 
    &lt;?xml version='1.0'?&gt;
    &lt;cubit version='1'&gt;
        &lt;status&gt;OK&lt;/status&gt;
    &lt;/cubit&gt;
    
     * </pre>
  
      * @param path (required)
            The path to the file being operated on. For example, if the complete file URL is <code>/pbl/zork/pub/foo/bar/test.txt</code>, the <code>path</code> would be <code>/foo/bar/test.txt</code>
  
      * @param proj (required)
            The name of the project which contains the file we are operating on.
  
      * @param desc (required)
            The new text description of the file. This description will completely replace any description currently set for the file.
  
      * @param comment 
            An optional comment to leave about the operation being performed. The comment will not appear in the  PBL, but it will be in the audit log entry for this event.
  
      * @param type (required)
            The type of file that we are operating on. Valid values are '<code>pub</code>' and '<code>priv</code>'.
  */
    @Signed
    @CgiMethod("pbl_changedesc")
    @Version(1)
    public Response pblChangeDesc(
        @Required @Param("path") String path,
        @Required @Param("proj") String proj,
        @Required @Param("desc") String desc,
        @Param("comment") String comment,
        @Required @Param("type") String type) throws IOException;


    /**
     * Project Build Library (PBL) file and directory delete interface. This function is used to permanently remove files and directories in the Project Build Library. <strong>Unless you are building your own PBL client, this function will not be very useful to you.</strong> 
     *
     * <h2>Example Response</h2>
     * <pre>
     * 
    &lt;?xml version='1.0'?&gt;
    &lt;cubit version='1'&gt;
        &lt;status&gt;OK&lt;/status&gt;
    &lt;/cubit&gt;
    
     * </pre>
  
      * @param force 
            If the <code>force</code> option is present and set to <code>True</code>, and the specified <code>path</code> argument is a directory, a recursive delete of the directory will be performed. The only valid value for this parameter is <code>True</code>.
  
      * @param path (required)
            The path to the file being operated on. For example, if the complete file URL is <code>/pbl/zork/pub/foo/bar/test.txt</code>, the <code>path</code> would be <code>/foo/bar/test.txt</code>
  
      * @param proj (required)
            The name of the project which contains the file we are operating on.
  
      * @param comment 
            An optional comment to leave about the operation being performed. This will not appear in the PBL, but it will be in the audit log entry for this event.
  
      * @param dryrun (required)
            If this parameter is set to <code>True</code>, the specified <code>path</code> will not actually be deleted. The only valid value for this parameter is <code>True</code>.
  
      * @param type (required)
            The type of file that we are operating on. Valid values are '<code>pub</code>' and '<code>priv</code>'.
  */
    @Signed
    @CgiMethod("pbl_delete")
    @Version(1)
    public Response pblDelete(
        @Param("force") String force,
        @Required @Param("path") String path,
        @Required @Param("proj") String proj,
        @Param("comment") String comment,
        @Required @Param("dryrun") String dryrun,
        @Required @Param("type") String type) throws IOException;


    /**
     * Project Build Library (PBL) file and directory move interface. <strong>Unless you are building your own PBL client, this function will not be very useful to you.</strong> 
     *
     * <h2>Example Response</h2>
     * <pre>
     * 
    &lt;?xml version='1.0'?&gt;
    &lt;cubit version='1'&gt;
        &lt;status&gt;OK&lt;/status&gt;
    &lt;/cubit&gt;
    
     * </pre>
  
      * @param srcprj (required)
            The project in which the source file is located.
  
      * @param destprj 
            The destination project for the file. You must have permissions to upload files into both the <code>srcprj</code> and the <code>destprj</code>, or the move will fail. If not specified, defaults to <code>srcprj</code>.
  
      * @param force 
            If the <code>force</code> option is present, the file will be moved even if a file with that name currently exists, and the previous file will be deleted and replaced with this file. The only valid value for this parameter is <code>True</code>.
  
      * @param srctype (required)
            The source type of the file. Valid values are '<code>pub</code>' and '<code>priv</code>'.
  
      * @param srcpath (required)
            The path to the source file being operated on. For example, if the complete file URL is <code>/pbl/zork/pub/foo/bar/test.txt</code>, the <code>srcpath</code> would be <code>/foo/bar/test.txt</code>
  
      * @param comment 
            An optional comment to leave about the operation being performed. This will not appear in the PBL, but it will be in the audit log entry for this event.
  
      * @param destpath (required)
            The path to move the destination file to. For example, if the complete file URL is <code>/pbl/zork/pub/foo/bar/test.txt</code>, the <code>srcpath</code> would be <code>/foo/bar/test.txt</code>. Two important things to note about this parameter: <ol> <li>If you specify a path which does not exist, that path will be automatically created for you as part of the move. </li> <li>If the <code>destpath</code> parameter ends with a slash (&quot;/&quot;), the destination will be assumed to be a directory. If it does not end with a slash, the destination will be assumed to be a file. </li> </ol>
  
      * @param desttype 
            The destination type of the file. Valid values are '<code>pub</code>' and '<code>priv</code>'. If not specified, defaults to <code>srctype</code>.
  */
    @Signed
    @CgiMethod("pbl_move")
    @Version(1)
    public Response pblMove(
        @Required @Param("srcprj") String srcprj,
        @Param("destprj") String destprj,
        @Param("force") String force,
        @Required @Param("srctype") String srctype,
        @Required @Param("srcpath") String srcpath,
        @Param("comment") String comment,
        @Required @Param("destpath") String destpath,
        @Param("desttype") String desttype) throws IOException;


    /**
     * Project Build Library (PBL) file and directory upload interface. This function is used to create files and directories in the Project Build Library. <strong>Unless you are building your own PBL client, this function will not be very useful to you.</strong> 
     *
     * <h2>Example Response</h2>
     * <pre>
     * 
    &lt;?xml version='1.0'?&gt;
    &lt;cubit version='1'&gt;
        &lt;status&gt;OK&lt;/status&gt;
    &lt;/cubit&gt;
    
     * </pre>
  
      * @param desc 
            The text description of the file.
  
      * @param md5sum (required)
            The md5 checksum of the file being uploaded.
  
      * @param file (required)
            URL-encoded name and contents of the file, encoded as per <a href="http://www.faqs.org/rfcs/rfc1867.html">RFC 1867</a>.
  
      * @param proj (required)
            The name of the project which contains the file we are operating on.
  
      * @param force 
            If the <code>force</code> option is present, the file will be uploaded even if a file with that name currently exists. A file cannot be uploaded over a directory of the same name, even if the <code>force</code> parameter is present. The only valid value for this parameter is <code>True</code>.
  
      * @param comment 
            An optional comment to leave about the operation being performed. This will not appear in the PBL, but it will be in the audit log entry for this event.
  
      * @param type (required)
            The type of file that we are operating on. Valid values are '<code>pub</code>' and '<code>priv</code>'.
  
      * @param path (required)
            The path to the file being operated on. For example, if the complete file URL is <code>/pbl/zork/pub/foo/bar/test.txt</code>, the <code>path</code> would be <code>/foo/bar</code>. Note: the <code>path</code> parameter is used slightly differently in this method than in other methods, since the filename is not appended to the end of the parameter.
  */
    @Signed
    @CgiMethod("pbl_upload")
    @Version(1)
    public Response pblUpload(
        @Param("desc") String desc,
        @Required @Param("md5sum") String md5sum,
        @Required @Param("file") String file,
        @Required @Param("proj") String proj,
        @Param("force") String force,
        @Param("comment") String comment,
        @Required @Param("type") String type,
        @Required @Param("path") String path) throws IOException;


    /**
     *  <p>The ProfileAdd method adds a profile to the system. The following conditions must hold for a profile to be added by name: <ol> <li>The <code>profile_name</code> must be specified.</li> <li>The <code>profile_file</code> must not specified.</li> <li>The profile must already exist in SVN.</li> <li>The user calling this method must be a Domain Admin.</li> </ol> The following conditions must hold for a profile to be uploaded: <ol> <li>The <code>profile_file</code> must be specified.</li> <li>The <code>profile_name</code> must not be specified</li> <li>The user calling this method must have permission to add profiles to the specified project.</li> </ol> </p> 
     *
     * <h2>Example Response</h2>
     * <pre>
     * 
    Successful addition of the profile rhel3_base:
    &lt;?xml version='1.0'?&gt;
    &lt;cubit version='1'&gt;
        &lt;status&gt;OK&lt;/status&gt;
        &lt;output&gt;rhel3_base&lt;/output&gt;
    &lt;/cubit&gt;

    If the user is unauthorized:
    &lt;?xml version='1.0'?&gt;
    &lt;cubit version='1'&gt;
        &lt;error&gt;Failed to add profile rhel3_base.&lt;/error&gt;
        &lt;output&gt;User 'userid' does not have Domain Admin rights.&lt;/output&gt;
    &lt;/cubit&gt;
    
     * </pre>
  
      * @param profile_file 
            The filename of a profile to be uploaded. The specified file must: <ol> <li>Exist on your local system.</li> <li>Contain a valid profile name. Profile names can only contain letters, numbers, underscores ("_"), and dashes ("-"). Profile names are case sensitive.<li> <li>Not currently exist as a profile name on the system.</li> <li>Be a valid XML file, and contain all the needed attributes for a Lab Management profile.</li> </ol>
  
      * @param owner 
            Lab Management user that this profile will be  associated with. The user must be a member of the owning project in order to be able to modify the profile. If unset, this profile will not belong to any particular user.
  
      * @param can_users_modify (required)
            Set this to <code>True</code> if user's with Root Access or better should be able to make modifications to the  project. If set to <code>False</code>, only the owning user and users with  Project Admin access (or better) will be able to modify the profile.
  
      * @param summary (required)
            Summary of the purpose of this profile.
  
      * @param profile_name 
            The name of a profile that already exists in Lab Management's Subversion Repository.
  
      * @param is_public (required)
            If the profile is public (i.e can be built by any project). Valid values are <code>True</code> or <code>False</code>.
  
      * @param project 
            Project that will own this profile. If unset, this profile will not belong to any particular project.
  
      * @param is_prebuilt (required)
            Set this to <code>True</code> if this profile a VMWare or other prebuilt image, <code>False </code> if this profile is installed via a network install method.
  */
    @Signed
    @CgiMethod("add_profile")
    @Version(1)
    public Response profileAdd(
        @Param("profile_file") String profile_file,
        @Param("owner") String owner,
        @Required @Param("can_users_modify") String can_users_modify,
        @Required @Param("summary") String summary,
        @Param("profile_name") String profile_name,
        @Required @Param("is_public") String is_public,
        @Param("project") String project,
        @Required @Param("is_prebuilt") String is_prebuilt) throws IOException;


    /**
     *  <p>The ProfileDelete method deletes a profile from the system. Profiles can be deleted under the following conditions: <ol> <li>No host has ever been built or is currently building with this profile. </li>The user calling this method has permission to modify this profile. <li> </li> </ol> </p>   
     *
     * <h2>Example Response</h2>
     * <pre>
     * 
    Successful delete of the profile rhel3_base:
    &lt;?xml version='1.0'?&gt;
    &lt;cubit version='1'&gt;
        &lt;status&gt;OK&lt;/status&gt;
        &lt;output&gt;rhel3_base&lt;/output&gt;
    &lt;/cubit&gt;

    If the user is unauthorized:
    &lt;?xml version='1.0'?&gt;
    &lt;cubit version='1'&gt;
        &lt;error&gt;0 of 1 profiles deleted successfully. Failed profiles below.&lt;/error&gt;
        &lt;output&gt;rhel3_base: You do not have modify rights on this profile.&lt;/output&gt;
    &lt;/cubit&gt;

    If a deletion of profiles partially succeeds:
    &lt;?xml version='1.0'?&gt;
    &lt;cubit version='1'&gt;
        &lt;error&gt;7 of 8 profiles deleted successfully. Failed profiles below.&lt;/error&gt;
        &lt;output&gt;rhel3_base: This profile has been used to build hosts.&lt;/output&gt;
    &lt;/cubit&gt;
    
     * </pre>
  
      * @param profiles (required)
            List of comma-separated, profile names to delete. Profiles must never have been used to build any hosts. The user invoking this API must have modify rights on the profiles.
  */
    @Signed
    @CgiMethod("delete_profile")
    @Version(1)
    public Response profileDelete(
        @Required @Param("profiles") String profiles) throws IOException;


    /**
     *  List the packages associated with the profile assigned to the calling host. 
     *
     * <h2>Example Response</h2>
     * <pre>
     * 
    Sample XML output:
    &lt;?xml version='1.0'?&gt;
    &lt;cubit version='1'&gt;
      &lt;package version="1.4.3-6"&gt;libtool-libs&lt;/package&gt;
      &lt;package version="2.1.15-10"&gt;cyrus-sasl-md5&lt;/package&gt;
      &lt;package version="20020927-11.30.4"&gt;iputils&lt;/package&gt;
      &lt;package version="3.03-28"&gt;perl-HTML-Tagset&lt;/package&gt;
      &lt;package version="1.4.1-2"&gt;python-optik&lt;/package&gt;
      ...
      &lt;package version="1.7-23"&gt;time&lt;/package&gt;
      &lt;package version="3.2.3-54"&gt;cpp&lt;/package&gt;
      &lt;package version="8.3.5-92.4"&gt;tcl&lt;/package&gt;
      &lt;package version="0.2.3-7.1"&gt;audiofile&lt;/package&gt;
    &lt;/cubit&gt;
  
    Sample text output:
    libtool-libs  1.4.3-6
    cyrus-sasl-md5  2.1.15-10
    iputils  20020927-11.30.4
    perl-HTML-Tagset  3.03-28
    python-optik  1.4.1-2
    ...
    time  1.7-23
    cpp  3.2.3-54
    tcl  8.3.5-92.4
    audiofile  0.2.3-7.1
    
     * </pre>
  
      * @param output (required)
            Output type, either 'txt' (for text output) or 'xml' (for XML output).
  */
    @CgiMethod("getmypkglist")
    @Version(1)
    public Response profileGetMyPkglist(
        @Required @Param("output") String output) throws IOException;


    /**
     *  List packages associated with a particular version or revision of  a profile. If neither are set, the version which has the package list would be selected. You must have permissions to view the profile in order to retrieve a package listing. The profile must either be public, or you must be a valid user in the project that owns the profile.  
     *
     * <h2>Example Response</h2>
     * <pre>
     * 
    (output='xml'):

    &lt;?xml version='1.0'?&gt;
    &lt;cubit version='1'&gt;
      &lt;package version="1.2.3"&gt;pkgname1&lt;/package&gt;
      &lt;package version="4.5.6"&gt;pkgname2&lt;/package&gt;
      &lt;package version="7.8.9"&gt;pkgname3&lt;/package&gt;
    &lt;/cubit&gt;

    (output='txt'):
    pkg1  1.2.3
    pkg2  4.5.6
    pkg3  7.8.9
    
     * </pre>
  
      * @param profile (required)
            Profile to get package list for.
  
      * @param output 
            Ouput mode. 'txt' or 'xml'
  
      * @param version 
            Version of profile to get package list for.
  
      * @param revision 
            Revision of profile to get package list for.
  */
    @Signed
    @CgiMethod("getpkglist")
    @Version(1)
    public Response profileGetPkglist(
        @Required @Param("profile") String profile,
        @Param("output") String output,
        @Param("version") Integer version,
        @Param("revision") Integer revision) throws IOException;


    /**
     *  The QueryAlloc method is used to determine, at either a <i>domain</i>, <i>project</i>, <i>user</i>, or <i>host</i> level, how hosts are allocated and who they are allocated to. Users are only allowed to get information about hosts which they have access to see. For example, if you are not a member of a project, you cannot query that project's host allocations. If you query the domain, you will only see allocation information for projects to which you belong. This method is used by Lab Management internally, and it is made available for users as well, since they may find this data useful.
     *
     * <h2>Example Response</h2>
     * <pre>
     * 
    Here is a sample output where we query type=host and
    name=cu011.dev.cubitdemo.net:

    &lt;?xml version='1.0'?&gt;
    &lt;cubit version='1'&gt;
      &lt;project name="zork"&gt;
        &lt;host version="2"&gt;
          &lt;name&gt;cu011.dev.cubitdemo.net&lt;/name&gt;
          &lt;alloc_user&gt;yz&lt;/alloc_user&gt;
          &lt;alloc_project&gt;zork&lt;/alloc_project&gt;
          &lt;labels&gt;
            &lt;label name="cubit_user"&gt;yz&lt;/label&gt;
            &lt;label name="cubit_project"&gt;zork&lt;/label&gt;
          &lt;/labels&gt;
        &lt;/host&gt;
      &lt;/project&gt;
    &lt;/cubit&gt;

    Here is a sample output where we query type=host,
    name=cu011.dev.cubitdemo.net and full=True:

    &lt;?xml version='1.0'?&gt;
    &lt;cubit version='1'&gt;
          &lt;project name=zork&gt;
            &lt;host version="2"&gt;
    &lt;name&gt;cu011.dev.cubitdemo.net&lt;/name&gt;
    &lt;alloc_user&gt;yz&lt;/alloc_user&gt;
    &lt;alloc_project&gt;zork&lt;/alloc_project&gt;
    &lt;hardware&gt;
            &lt;vendor&gt;Collabnet&lt;/vendor&gt;
            &lt;modelname&gt;HP DL380&lt;/modelname&gt;
            &lt;ncpu&gt;2&lt;/ncpu&gt;
            &lt;cpuarch&gt;i386&lt;/cpuarch&gt;
            &lt;cpuname&gt;Xeon&lt;/cpuname&gt;
            &lt;cpumhz&gt;1400&lt;/cpumhz&gt;
            &lt;memsize unit="MB"&gt;2048&lt;/memsize&gt;
            &lt;disksize unit="GB"&gt;144&lt;/disksize&gt;
    &lt;/hardware&gt;
    &lt;labels&gt;
      &lt;label name='cfprofile' rev='322' version='4'&gt;rhel3_base&lt;/label&gt;
        &lt;label name='install_mode'&gt;kickstart-net&lt;/label&gt;
      &lt;label name='cubit_state'&gt;Allocated&lt;/label&gt;
      &lt;label name='cubit_alloc_time'&gt;1170799967&lt;/label&gt;
      &lt;label name='cubit_state_mtime'&gt;1170799967&lt;/label&gt;
      &lt;label name='cubit_build_time'&gt;1169682748&lt;/label&gt;
      &lt;label name='cubit_project'&gt;zork&lt;/label&gt;
      &lt;label name='cubit_user'&gt;yz&lt;/label&gt;
      &lt;label name='vmware-server'/&gt;
      &lt;label name='cubit_lom_addr'&gt;cu3-l.sjc.collab.net&lt;/label&gt;
    &lt;/labels&gt;
    &lt;groups&gt;
      &lt;aigroup&gt;DEFAULT&lt;/aigroup&gt;
    &lt;/groups&gt;
    &lt;network&gt;
      &lt;routing&gt;
        &lt;default&gt;
          &lt;ipv4_addr&gt;192.168.202.1&lt;/ipv4_addr&gt;
         &lt;/default&gt;
      &lt;/routing&gt;
         &lt;interface&gt;
             &lt;name&gt;eth0&lt;/name&gt;
             &lt;sol_name&gt;e1000g0&lt;/sol_name&gt;
             &lt;mac_addr&gt;00:16:35:c3:9b:ed&lt;/mac_addr&gt;
             &lt;bootproto&gt;static&lt;/bootproto&gt;
             &lt;addr&gt;
                 &lt;ipv4_addr&gt;192.168.202.21&lt;/ipv4_addr&gt;
                 &lt;ipv4_mask&gt;255.255.255.0&lt;/ipv4_mask&gt;
                 &lt;dnsname&gt;cu011.dev.cubitdemo.net&lt;/dnsname&gt;
             &lt;/addr&gt;
         &lt;/interface&gt;
    &lt;/network&gt;
    &lt;/host&gt;

          &lt;/project&gt;
    &lt;/cubit&gt;

    Here is a sample output where we query type=domain:

    &lt;?xml version='1.0'?&gt;
    &lt;cubit version='1'&gt;
      &lt;domain&gt;
      &lt;project name="zork"&gt;
          &lt;host&gt;
            &lt;name&gt;cu011.dev.cubitdemo.net&lt;/name&gt;
            &lt;alloc_user&gt;yz&lt;/alloc_user&gt;
            &lt;alloc_project&gt;zork&lt;/alloc_project&gt;
            &lt;labels&gt;
              &lt;label name="cubit_user"&gt;yz&lt;/label&gt;
              &lt;label name="cubit_project"&gt;zork&lt;/label&gt;
            &lt;/labels&gt;
          &lt;/host&gt;
          &lt;host&gt;
            &lt;name&gt;cu012.dev.cubitdemo.net&lt;/name&gt;
            &lt;alloc_user&gt;yz&lt;/alloc_user&gt;
            &lt;alloc_project&gt;zork&lt;/alloc_project&gt;
            &lt;labels&gt;
              &lt;label name="cubit_user"&gt;yz&lt;/label&gt;
              &lt;label name="cubit_project"&gt;zork&lt;/label&gt;
            &lt;/labels&gt;
          &lt;/host&gt;
      &lt;/project&gt;
      &lt;/domain&gt;
    &lt;/cubit&gt;

    Here is a sample output where we query type=domain and full=True:

    &lt;?xml version='1.0'?&gt;
    &lt;cubit version='1'&gt;
      &lt;domain&gt;
      &lt;project name="zork"&gt;
          &lt;host version="2"&gt;
    &lt;name&gt;cu011.dev.cubitdemo.net&lt;/name&gt;
    &lt;alloc_user&gt;yz&lt;/alloc_user&gt;
    &lt;alloc_project&gt;zork&lt;/alloc_project&gt;
    &lt;hardware&gt;
            &lt;vendor&gt;Collabnet&lt;/vendor&gt;
            &lt;modelname&gt;HP DL380&lt;/modelname&gt;
            &lt;ncpu&gt;2&lt;/ncpu&gt;
            &lt;cpuarch&gt;i386&lt;/cpuarch&gt;
            &lt;cpuname&gt;Xeon&lt;/cpuname&gt;
            &lt;cpumhz&gt;1400&lt;/cpumhz&gt;
            &lt;memsize unit="MB"&gt;2048&lt;/memsize&gt;
            &lt;disksize unit="GB"&gt;144&lt;/disksize&gt;
    &lt;/hardware&gt;
    &lt;labels&gt;
      &lt;label name='cfprofile' rev='322' version='4'&gt;rhel3_base&lt;/label&gt;
        &lt;label name='install_mode'&gt;kickstart-net&lt;/label&gt;
      &lt;label name='cubit_state'&gt;Allocated&lt;/label&gt;
      &lt;label name='cubit_alloc_time'&gt;1170799967&lt;/label&gt;
      &lt;label name='cubit_state_mtime'&gt;1170799967&lt;/label&gt;
      &lt;label name='cubit_build_time'&gt;1169682748&lt;/label&gt;
      &lt;label name='cubit_project'&gt;zork&lt;/label&gt;
      &lt;label name='cubit_user'&gt;yz&lt;/label&gt;
      &lt;label name='vmware-server'/&gt;
      &lt;label name='cubit_lom_addr'&gt;cu3-l.sjc.collab.net&lt;/label&gt;
    &lt;/labels&gt;
    &lt;groups&gt;
      &lt;aigroup&gt;DEFAULT&lt;/aigroup&gt;
    &lt;/groups&gt;
    &lt;network&gt;
      &lt;routing&gt;
        &lt;default&gt;
          &lt;ipv4_addr&gt;192.168.202.1&lt;/ipv4_addr&gt;
         &lt;/default&gt;
      &lt;/routing&gt;
         &lt;interface&gt;
             &lt;name&gt;eth0&lt;/name&gt;
             &lt;sol_name&gt;e1000g0&lt;/sol_name&gt;
             &lt;mac_addr&gt;00:16:35:c3:9b:ed&lt;/mac_addr&gt;
             &lt;bootproto&gt;static&lt;/bootproto&gt;
             &lt;addr&gt;
                 &lt;ipv4_addr&gt;192.168.202.21&lt;/ipv4_addr&gt;
                 &lt;ipv4_mask&gt;255.255.255.0&lt;/ipv4_mask&gt;
                 &lt;dnsname&gt;cu011.dev.cubitdemo.net&lt;/dnsname&gt;
             &lt;/addr&gt;
         &lt;/interface&gt;
    &lt;/network&gt;
    &lt;/host&gt;

          &lt;host version="2"&gt;
    &lt;name&gt;cu012.dev.cubitdemo.net&lt;/name&gt;
    &lt;alloc_user&gt;yz&lt;/alloc_user&gt;
    &lt;alloc_project&gt;zork&lt;/alloc_project&gt;
    &lt;hardware&gt;
            &lt;vendor&gt;Collabnet&lt;/vendor&gt;
            &lt;modelname&gt;HP DL380&lt;/modelname&gt;
            &lt;ncpu&gt;1&lt;/ncpu&gt;
            &lt;cpuarch&gt;i386&lt;/cpuarch&gt;
            &lt;cpuname&gt;Xeon&lt;/cpuname&gt;
            &lt;cpumhz&gt;1400&lt;/cpumhz&gt;
            &lt;memsize unit="MB"&gt;2048&lt;/memsize&gt;
            &lt;disksize unit="GB"&gt;144&lt;/disksize&gt;
    &lt;/hardware&gt;
    &lt;labels&gt;
      &lt;label name='cfprofile' rev='322' version='4'&gt;rhel3_all&lt;/label&gt;
        &lt;label name='install_mode'&gt;kickstart-net&lt;/label&gt;
      &lt;label name='cubit_state'&gt;Allocated&lt;/label&gt;
      &lt;label name='cubit_alloc_time'&gt;1170800012&lt;/label&gt;
      &lt;label name='cubit_state_mtime'&gt;1170800012&lt;/label&gt;
      &lt;label name='cubit_build_time'&gt;1169687903&lt;/label&gt;
      &lt;label name='cubit_project'&gt;zork&lt;/label&gt;
      &lt;label name='cubit_user'&gt;yz&lt;/label&gt;
      &lt;label name='vmware-server'/&gt;
      &lt;label name='cubit_lom_addr'&gt;cu4-l.sjc.collab.net&lt;/label&gt;
    &lt;/labels&gt;
    &lt;groups&gt;
      &lt;aigroup&gt;DEFAULT&lt;/aigroup&gt;
    &lt;/groups&gt;
    &lt;network&gt;
      &lt;routing&gt;
        &lt;default&gt;
          &lt;ipv4_addr&gt;192.168.202.1&lt;/ipv4_addr&gt;
         &lt;/default&gt;
      &lt;/routing&gt;
         &lt;interface&gt;
             &lt;name&gt;eth0&lt;/name&gt;
             &lt;sol_name&gt;e1000g0&lt;/sol_name&gt;
             &lt;mac_addr&gt;00:16:35:5a:fe:39&lt;/mac_addr&gt;
             &lt;bootproto&gt;static&lt;/bootproto&gt;
             &lt;addr&gt;
                 &lt;ipv4_addr&gt;192.168.202.22&lt;/ipv4_addr&gt;
                 &lt;ipv4_mask&gt;255.255.255.0&lt;/ipv4_mask&gt;
                 &lt;dnsname&gt;cu012.dev.cubitdemo.net&lt;/dnsname&gt;
             &lt;/addr&gt;
         &lt;/interface&gt;
    &lt;/network&gt;
    &lt;/host&gt;
    &lt;/project&gt;
    &lt;/domain&gt;
    &lt;/cubit&gt;

    Here is a sample output where we query type=project and name=zork:

    &lt;?xml version='1.0'?&gt;
    &lt;cubit version='1'&gt;
      &lt;project name="zork"&gt;
          &lt;host version="2"&gt;
            &lt;name&gt;cu011.dev.cubitdemo.net&lt;/name&gt;
            &lt;alloc_user&gt;yz&lt;/alloc_user&gt;
            &lt;alloc_project&gt;zork&lt;/alloc_project&gt;
            &lt;labels&gt;
              &lt;label name="cubit_user"&gt;yz&lt;/label&gt;
              &lt;label name="cubit_project"&gt;zork&lt;/label&gt;
            &lt;/labels&gt;
          &lt;/host&gt;
          &lt;host version="2"&gt;
            &lt;name&gt;cu012.dev.cubitdemo.net&lt;/name&gt;
            &lt;alloc_user&gt;yz&lt;/alloc_user&gt;
            &lt;alloc_project&gt;zork&lt;/alloc_project&gt;
            &lt;labels&gt;
              &lt;label name="cubit_user"&gt;yz&lt;/label&gt;
              &lt;label name="cubit_project"&gt;zork&lt;/label&gt;
            &lt;/labels&gt;
          &lt;/host&gt;
          &lt;host version="2"&gt;
            &lt;name&gt;cu013.dev.cubitdemo.net&lt;/name&gt;
            &lt;alloc_user&gt;grue&lt;/alloc_user&gt;
            &lt;alloc_project&gt;zork&lt;/alloc_project&gt;
            &lt;labels&gt;
              &lt;label name="cubit_user"&gt;grue&lt;/label&gt;
              &lt;label name="cubit_project"&gt;zork&lt;/label&gt;
            &lt;/labels&gt;
          &lt;/host&gt;
          &lt;host version="2"&gt;
            &lt;name&gt;cu014.dev.cubitdemo.net&lt;/name&gt;
            &lt;alloc_user&gt;root&lt;/alloc_user&gt;
            &lt;alloc_project&gt;zork&lt;/alloc_project&gt;
            &lt;labels&gt;
              &lt;label name="cubit_user"&gt;root&lt;/label&gt;
              &lt;label name="cubit_project"&gt;zork&lt;/label&gt;
            &lt;/labels&gt;
          &lt;/host&gt;
          &lt;host version="2"&gt;
            &lt;name&gt;cu019.dev.cubitdemo.net&lt;/name&gt;
            &lt;alloc_user&gt;root&lt;/alloc_user&gt;
            &lt;alloc_project&gt;zork&lt;/alloc_project&gt;
            &lt;labels&gt;
              &lt;label name="cubit_user"&gt;root&lt;/label&gt;
              &lt;label name="cubit_project"&gt;zork&lt;/label&gt;
            &lt;/labels&gt;
          &lt;/host&gt;
          &lt;host version="2"&gt;
            &lt;name&gt;cu022.dev.cubitdemo.net&lt;/name&gt;
            &lt;alloc_user&gt;grue&lt;/alloc_user&gt;
            &lt;alloc_project&gt;zork&lt;/alloc_project&gt;
            &lt;labels&gt;
              &lt;label name="cubit_user"&gt;grue&lt;/label&gt;
              &lt;label name="cubit_project"&gt;zork&lt;/label&gt;
            &lt;/labels&gt;
          &lt;/host&gt;
          &lt;host version="2"&gt;
            &lt;name&gt;cu091.dev.cubitdemo.net&lt;/name&gt;
            &lt;alloc_user&gt;root&lt;/alloc_user&gt;
            &lt;alloc_project&gt;zork&lt;/alloc_project&gt;
            &lt;labels&gt;
              &lt;label name="cubit_user"&gt;root&lt;/label&gt;
              &lt;label name="cubit_project"&gt;zork&lt;/label&gt;
            &lt;/labels&gt;
          &lt;/host&gt;
      &lt;/project&gt;
    &lt;/cubit&gt;

    Here is a sample output where we query type=project, name=zork and
    full=True:

    &lt;?xml version='1.0'?&gt;
    &lt;cubit version='1'&gt;
      &lt;project name="zork"&gt;
          &lt;host version="2"&gt;
    &lt;name&gt;cu011.dev.cubitdemo.net&lt;/name&gt;
    &lt;alloc_user&gt;yz&lt;/alloc_user&gt;
    &lt;alloc_project&gt;zork&lt;/alloc_project&gt;
    &lt;hardware&gt;
            &lt;vendor&gt;Collabnet&lt;/vendor&gt;
            &lt;modelname&gt;HP DL380&lt;/modelname&gt;
            &lt;ncpu&gt;2&lt;/ncpu&gt;
            &lt;cpuarch&gt;i386&lt;/cpuarch&gt;
            &lt;cpuname&gt;Xeon&lt;/cpuname&gt;
            &lt;cpumhz&gt;1400&lt;/cpumhz&gt;
            &lt;memsize unit="MB"&gt;2048&lt;/memsize&gt;
            &lt;disksize unit="GB"&gt;144&lt;/disksize&gt;
    &lt;/hardware&gt;
    &lt;labels&gt;
      &lt;label name='cfprofile' rev='322' version='4'&gt;rhel3_base&lt;/label&gt;
        &lt;label name='install_mode'&gt;kickstart-net&lt;/label&gt;
      &lt;label name='cubit_state'&gt;Allocated&lt;/label&gt;
      &lt;label name='cubit_alloc_time'&gt;1170799967&lt;/label&gt;
      &lt;label name='cubit_state_mtime'&gt;1170799967&lt;/label&gt;
      &lt;label name='cubit_build_time'&gt;1169682748&lt;/label&gt;
      &lt;label name='cubit_project'&gt;zork&lt;/label&gt;
      &lt;label name='cubit_user'&gt;yz&lt;/label&gt;
      &lt;label name='vmware-server'/&gt;
      &lt;label name='cubit_lom_addr'&gt;cu3-l.sjc.collab.net&lt;/label&gt;
    &lt;/labels&gt;
    &lt;groups&gt;
      &lt;aigroup&gt;DEFAULT&lt;/aigroup&gt;
    &lt;/groups&gt;
    &lt;network&gt;
      &lt;routing&gt;
        &lt;default&gt;
          &lt;ipv4_addr&gt;192.168.202.1&lt;/ipv4_addr&gt;
         &lt;/default&gt;
      &lt;/routing&gt;
         &lt;interface&gt;
             &lt;name&gt;eth0&lt;/name&gt;
             &lt;sol_name&gt;e1000g0&lt;/sol_name&gt;
             &lt;mac_addr&gt;00:16:35:c3:9b:ed&lt;/mac_addr&gt;
             &lt;bootproto&gt;static&lt;/bootproto&gt;
             &lt;addr&gt;
                 &lt;ipv4_addr&gt;192.168.202.21&lt;/ipv4_addr&gt;
                 &lt;ipv4_mask&gt;255.255.255.0&lt;/ipv4_mask&gt;
                 &lt;dnsname&gt;cu011.dev.cubitdemo.net&lt;/dnsname&gt;
             &lt;/addr&gt;
         &lt;/interface&gt;
    &lt;/network&gt;
    &lt;/host&gt;

          &lt;host version="2"&gt;
    &lt;name&gt;cu012.dev.cubitdemo.net&lt;/name&gt;
    &lt;alloc_user&gt;yz&lt;/alloc_user&gt;
    &lt;alloc_project&gt;zork&lt;/alloc_project&gt;
    &lt;hardware&gt;
            &lt;vendor&gt;Collabnet&lt;/vendor&gt;
            &lt;modelname&gt;HP DL380&lt;/modelname&gt;
            &lt;ncpu&gt;1&lt;/ncpu&gt;
            &lt;cpuarch&gt;i386&lt;/cpuarch&gt;
            &lt;cpuname&gt;Xeon&lt;/cpuname&gt;
            &lt;cpumhz&gt;1400&lt;/cpumhz&gt;
            &lt;memsize unit="MB"&gt;2048&lt;/memsize&gt;
            &lt;disksize unit="GB"&gt;144&lt;/disksize&gt;
    &lt;/hardware&gt;
    &lt;labels&gt;
      &lt;label name='cfprofile' rev='322' version='4'&gt;rhel3_all&lt;/label&gt;
        &lt;label name='install_mode'&gt;kickstart-net&lt;/label&gt;
      &lt;label name='cubit_state'&gt;Allocated&lt;/label&gt;
      &lt;label name='cubit_alloc_time'&gt;1170800012&lt;/label&gt;
      &lt;label name='cubit_state_mtime'&gt;1170800012&lt;/label&gt;
      &lt;label name='cubit_build_time'&gt;1169687903&lt;/label&gt;
      &lt;label name='cubit_project'&gt;zork&lt;/label&gt;
      &lt;label name='cubit_user'&gt;yz&lt;/label&gt;
      &lt;label name='vmware-server'/&gt;
      &lt;label name='cubit_lom_addr'&gt;cu4-l.sjc.collab.net&lt;/label&gt;
    &lt;/labels&gt;
    &lt;groups&gt;
      &lt;aigroup&gt;DEFAULT&lt;/aigroup&gt;
    &lt;/groups&gt;
    &lt;network&gt;
      &lt;routing&gt;
        &lt;default&gt;
          &lt;ipv4_addr&gt;192.168.202.1&lt;/ipv4_addr&gt;
         &lt;/default&gt;
      &lt;/routing&gt;
         &lt;interface&gt;
             &lt;name&gt;eth0&lt;/name&gt;
             &lt;sol_name&gt;e1000g0&lt;/sol_name&gt;
             &lt;mac_addr&gt;00:16:35:5a:fe:39&lt;/mac_addr&gt;
             &lt;bootproto&gt;static&lt;/bootproto&gt;
             &lt;addr&gt;
                 &lt;ipv4_addr&gt;192.168.202.22&lt;/ipv4_addr&gt;
                 &lt;ipv4_mask&gt;255.255.255.0&lt;/ipv4_mask&gt;
                 &lt;dnsname&gt;cu012.dev.cubitdemo.net&lt;/dnsname&gt;
             &lt;/addr&gt;
         &lt;/interface&gt;
    &lt;/network&gt;
    &lt;/host&gt;

          &lt;host version="2"&gt;
    &lt;name&gt;cu013.dev.cubitdemo.net&lt;/name&gt;
    &lt;alloc_user&gt;grue&lt;/alloc_user&gt;
    &lt;alloc_project&gt;zork&lt;/alloc_project&gt;
    &lt;hardware&gt;
            &lt;vendor&gt;Collabnet&lt;/vendor&gt;
            &lt;modelname&gt;HP DL380&lt;/modelname&gt;
            &lt;ncpu&gt;1&lt;/ncpu&gt;
            &lt;cpuarch&gt;i386&lt;/cpuarch&gt;
            &lt;cpuname&gt;Xeon&lt;/cpuname&gt;
            &lt;cpumhz&gt;1400&lt;/cpumhz&gt;
            &lt;memsize unit="MB"&gt;1024&lt;/memsize&gt;
            &lt;disksize unit="GB"&gt;25&lt;/disksize&gt;
    &lt;/hardware&gt;
    &lt;uuid&gt;51 51 bb a0 00 15 15 51-81 9d fb 47 77 00 51 61&lt;/uuid&gt;
    &lt;labels&gt;
      &lt;label name='cfprofile' rev='322' version='6'&gt;rhel4_all&lt;/label&gt;
        &lt;label name='install_mode'&gt;kickstart-net&lt;/label&gt;
      &lt;label name='cubit_state'&gt;Allocated&lt;/label&gt;
      &lt;label name='cubit_alloc_time'&gt;1170960674&lt;/label&gt;
      &lt;label name='cubit_state_mtime'&gt;1170963906&lt;/label&gt;
      &lt;label name='cubit_build_time'&gt;1170963906&lt;/label&gt;
      &lt;label name='cubit_project'&gt;zork&lt;/label&gt;
      &lt;label name='cubit_user'&gt;grue&lt;/label&gt;
      &lt;label name='vmware-guest'&gt;cu011.dev.cubitdemo.net&lt;/label&gt;
      &lt;label name='cubit_lom_addr'&gt;cu011.dev.cubitdemo.net&lt;/label&gt;
    &lt;/labels&gt;
    &lt;groups&gt;
      &lt;aigroup&gt;DEFAULT&lt;/aigroup&gt;
    &lt;/groups&gt;
    &lt;network&gt;
      &lt;routing&gt;
        &lt;default&gt;
          &lt;ipv4_addr&gt;192.168.202.1&lt;/ipv4_addr&gt;
         &lt;/default&gt;
      &lt;/routing&gt;
         &lt;interface&gt;
             &lt;name&gt;eth0&lt;/name&gt;
             &lt;sol_name&gt;e1000g0&lt;/sol_name&gt;
             &lt;mac_addr&gt;00:50:56:00:00:01&lt;/mac_addr&gt;
             &lt;bootproto&gt;static&lt;/bootproto&gt;
             &lt;addr&gt;
                 &lt;ipv4_addr&gt;192.168.202.23&lt;/ipv4_addr&gt;
                 &lt;ipv4_mask&gt;255.255.255.0&lt;/ipv4_mask&gt;
                 &lt;dnsname&gt;cu013.dev.cubitdemo.net&lt;/dnsname&gt;
             &lt;/addr&gt;
         &lt;/interface&gt;
    &lt;/network&gt;
    &lt;/host&gt;
      &lt;/project&gt;
    &lt;/cubit&gt;

    
     * </pre>
  
      * @param name 
            The name of the host, project, or user to be queried. If type=domain, this argument is not required. If type={host,project} then this argument is required. If type=user, this argument is optional, defaulting to the name of the user who you authenticate as. Only Lab Management Domain Admins are allowed to query user allocations for users other than themselves.
  
      * @param full 
            If full=true then the complete information about the host is printed.
  
      * @param maxhosts 
            The maximum number of hosts to return for the query. If type=domain, this will be the maximum number of hosts to return per project (i.e. if this is set to 5 and there are two  projects in the domain, up to 10 hosts may be returned). If type=host, this parameter will not be used. If maxhosts is set, the returned hosts will be sorted by the host's name.
  
      * @param type (required)
            The type of service. Valid values are <code>host</code>, <code>project</code>, <code>user</code> and <code>domain</code>.
  
      * @param skiphosts 
            The number of initial hosts that will be  skipped over when returning the results. This only has an effect when maxhosts is also used. If type=domain, the hosts skipped are per per project. If type=hosts, this paramenter will not be used. 
  */
    @Signed
    @CgiMethod("query_alloc")
    @Version(1)
    public Response queryAlloc(
        @Param("name") String name,
        @Param("full") String full,
        @Param("maxhosts") Integer maxhosts,
        @Required @Param("type") String type,
        @Param("skiphosts") Integer  skiphosts) throws IOException;


    /**
     *  The QueryMembershipMethod method is used to determine the projects and the hosts for which the user have permission to access. If name parameter is not passed, the permission details of the initiating user will be displayed. Only Lab Management Domain Admins are permitted to query users other than themselves.
     *
     * <h2>Example Response</h2>
     * <pre>
     * 
    Here is a sample output where we query name=grue:

    &lt;?xml version='1.0'?&gt;
    &lt;cubit version='1'&gt;
      &lt;user name="grue"&gt;
        &lt;project name="testing"&gt;
          &lt;summary&gt;Cubit Testing&lt;/summary&gt;
          &lt;roles&gt;CUBIT - Domain Admin&lt;/roles&gt;
        &lt;/project&gt;
        &lt;project name="zim"&gt;
          &lt;summary&gt;invador&lt;/summary&gt;
          &lt;roles&gt;CUBIT - Domain Admin&lt;/roles&gt;
        &lt;/project&gt;
        &lt;project name="zork"&gt;
          &lt;summary&gt;For dorks&lt;/summary&gt;
          &lt;roles&gt;CUBIT - Domain Admin&lt;/roles&gt;
        &lt;/project&gt;
      &lt;/user&gt;
    &lt;/cubit&gt;

    
     * </pre>
  
      * @param name 
            The name of the user to get the permission details. This argument is optional, defaulting to the name of the user who you authenticate as. Only Lab Management Domain Admins are permitted to query users other than themselves.
  */
    @Signed
    @CgiMethod("query_membership")
    @Version(1)
    public Response queryMembership(
        @Param("name") String  name) throws IOException;


    /**
     *  Return the status of the Lab Management web service. This provides some  indication of whether or not the Lab Management web service is working properly. The only status returned is <code>OK</code>. 
     *
     * <h2>Example Response</h2>
     * <pre>
     * 
    &lt;?xml version='1.0'?&gt;
    &lt;cubit version='1'&gt;
        &lt;status&gt;OK&lt;/status&gt;
    &lt;/cubit&gt;
    
     * </pre>
  */
    @CgiMethod("status")
    @Version(1)
    public Response status(
) throws IOException;


    /**
     *  Return the status of the Lab Management web service, and the name of the authenticated user when authentication is used via a signed method. This provides proof that the API, and authentication to the API are working properly. The only status returned is <code>OK</code>. If the authentication is not successful, you will get a <code>Permission Denied</code> error. If the API key is expired, you will get a <code>Permission Denied: API key expired</code> error. 
     *
     * <h2>Example Response</h2>
     * <pre>
     * 
    &lt;?xml version='1.0'?&gt;
    &lt;cubit version='1'&gt;
        &lt;status&gt;OK&lt;/status&gt;
        &lt;userid&gt;grue&lt;/userid&gt;
    &lt;/cubit&gt;
    
     * </pre>
  */
    @Signed
    @CgiMethod("status_signed")
    @Version(1)
    public Response statusSigned(
) throws IOException;


    /**
     *  Given a userid and a hostname, return whether or not the user is authorized to login provided that the appropriate credentials are presented. The HTTP response code will always be 200 for a successful query whether or not access is permitted. The document body will be text only, and contain one of the following: <ul> <li><code><strong>0</strong></code><br/>&nbsp;&nbsp; no access</li> <li><code><strong>1</strong></code><br/>&nbsp;&nbsp; user level access</li> <li><code><strong>2</strong></code><br/>&nbsp;&nbsp; root level access</li> <li><code><strong>3</strong></code><br/>&nbsp;&nbsp; host owner access</li> <li><code><strong>4</strong></code><br/>&nbsp;&nbsp; project admin access</li> </ul> 
     *
     * <h2>Example Response</h2>
     * <pre>
     * 
    3
    
     * </pre>
  
      * @param host (required)
            The fully qualified hostname of the host to  test for access.
  */
    @CgiMethod("can_login")
    @Version(1)
    public Response userCanLogin(
        @Required @Param("host") String host) throws IOException;

}